@@ -2,8 +2,8 @@ package MooseX::Getopt;
 BEGIN {
   $MooseX::Getopt::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $MooseX::Getopt::VERSION = '0.37';
+{
+  $MooseX::Getopt::VERSION = '0.39';
 }
 # ABSTRACT: A Moose role for processing command line options
 
@@ -236,6 +236,12 @@ This accessor contains an arrayref of leftover C<@ARGV> elements that
 L<Getopt::Long> did not parse.  Note that the real C<@ARGV> is left
 un-mangled.
 
+B<Important>: By default, L<Getopt::Long> will reject unrecognized I<options>
+(that is, options that do not correspond with attributes using the Getopt
+trait). To disable this, and allow options to also be saved in C<extra_argv> (for example to pass along to another class's C<new_with_options>), enable the
+C<pass_through> option of L<Getopt::Long> for your class:  C<use Getopt::Long
+qw(:config pass_through);>
+
 =head2 B<usage>
 
 This accessor contains the L<Getopt::Long::Descriptive::Usage> object (if
@@ -258,6 +264,14 @@ L<MooseX::Getopt::ProcessedArgv> object. C<new_with_options> uses this
 method internally, so modifying this method via subclasses/roles will affect
 C<new_with_options>.
 
+=head2 More Customization Options
+
+See L<Getopt::Long#Configuring_Getopt::Long> for many other customizations you
+can make to how options are parsed. Simply C<use Getopt::Long qw(:config
+other_options...)> in your class to set these.
+
+=back
+
 =head1 AUTHORS
 
 =over 4
@@ -314,7 +328,7 @@ Jonathan Swartz <swartz@pobox.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Infinity Interactive, Inc.
+This software is copyright (c) 2012 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
