@@ -2,8 +2,8 @@ package MooseX::Getopt::Meta::Attribute::NoGetopt;
 BEGIN {
   $MooseX::Getopt::Meta::Attribute::NoGetopt::AUTHORITY = 'cpan:STEVAN';
 }
-BEGIN {
-  $MooseX::Getopt::Meta::Attribute::NoGetopt::VERSION = '0.31';
+{
+  $MooseX::Getopt::Meta::Attribute::NoGetopt::VERSION = '0.39';
 }
 # ABSTRACT: Optional meta attribute for ignoring params
 
@@ -17,12 +17,6 @@ no Moose;
 # register this as a metaclass alias ...
 package # stop confusing PAUSE
     Moose::Meta::Attribute::Custom::NoGetopt;
-BEGIN {
-  $Moose::Meta::Attribute::Custom::NoGetopt::AUTHORITY = 'cpan:STEVAN';
-}
-BEGIN {
-  $Moose::Meta::Attribute::Custom::NoGetopt::VERSION = '0.31';
-}
 sub register_implementation { 'MooseX::Getopt::Meta::Attribute::NoGetopt' }
 
 1;
@@ -104,11 +98,19 @@ Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
 
 Chris Prather <perigrin@cpan.org>
 
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Infinity Interactive, Inc.
+This software is copyright (c) 2012 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
